/*
 *  Copyright (C) 2001 Jorn Baayen
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2, or (at your option)
 *  any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

#include "prefs.h"

#ifdef __cplusplus
extern "C" {
#endif

/* toolbar_editor.c */
void toolbar_editor_init (void);
void toolbar_editor_save (void);
gint toolbar_editor_insert_item (GtkCList *clist, ToolbarItemType type);
void toolbar_editor_remove_item (GtkCList *clist, ToolbarItemType type);

#ifdef __cplusplus
}
#endif
